{-# LANGUAGE CPP #-}
#define PLATFORM_NAME   Posix
#define IS_WINDOWS      0
#include "Include.hs"
